﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace ConditionMapping
{
    static public class DataBuilder
    {
        private static string lastNameString = "Shea|Rouse|Hartley|Mayfield|Elder|Rankin|Hanna|Cowan|Lucero|Arroyo|Slaughter|Haas|Oconnell|Minor|Kendrick|Shirley|Kendall|Boucher|Archer|Boggs|Odell|Dougherty|Andersen|Newell|Crowe|Wang|Friedman|Bland|Swain|Holley|Felix|Pearce|Childs|Yarbrough|Galvan|Proctor|Meeks|Lozano|Mora|Rangel|Bacon|Villanueva|Schaefer|Rosado|Helms|Boyce|Goss|Stinson|Smart|Lake|Ibarra|Hutchins|Covington|Reyna|Gregg|Werner|Crowley|Hatcher|Mackey|Bunch|Womack|Polk|Jamison|Dodd|Childress|Childers|Camp|Villa|Dye|Springer|Mahoney|Dailey|Belcher|Lockhart|Griggs|Costa|Connor|Brandt|Winter|Walden|Moser|Tracy|Tatum|Mccann|Akers|Lutz|Pryor|Law|Orozco|Mcallister|Lugo|Davies|Shoemaker|Madison|Rutherford|Newsome|Magee|Chamberlain|Blanton|Simms|Godfrey|Flanagan|Crum|Cordova|Escobar|Downing|Sinclair|Donahue|Krueger|Mcginnis|Gore|Farris|Webber|Corbett|Andrade|Starr|Lyon|Yoder|Hastings|Mcgrath|Spivey|Krause|Harden|Crabtree|Kirkpatrick|Hollis|Brandon|Arrington|Ervin|Clifton|Ritter|Mcghee|Bolden|Maloney|Gagnon";
        private static string firstNameString = "Tori|Octavia|Jade|Denice|Germaine|Sierra|Michell|Cortney|Nelly|Doretha|Sydney|Deidra|Monika|Lashonda|Judi|Chelsey|Antionette|Margot|Bobby|Adelaide|Nan|Leeann|Elisha|Dessie|Libby|Kathi|Gayla|Latanya|Mina|Mellisa|Kimberlee|Jasmin|Renae|Zelda|Elda|Ma|Justina|Gussie|Emilie|Camilla|Abbie|Rocio|Kaitlyn|Jesse|Edythe|Ashleigh|Selina|Lakesha|Geri|Allene|Pamala|Michaela|Dayna|Caryn|Rosalia|Sun|Jacquline|Rebeca|Marybeth|Krystle|Iola|Dottie|Bennie|Belle|Aubrey|Griselda|Ernestina|Elida|Adrianne|Demetria|Delma|Chong|Jaqueline|Destiny|Arleen|Virgina|Retha|Fatima|Tillie|Eleanore|Cari|Treva|Birdie|Wilhelmina|Rosalee|Maurine|Latrice|Yong|Jena|Taryn|Elia|Debby|Maudie|Jeanna|Delilah|Catrina|Shonda|Hortencia|Theodora|Teresita|Robbin|Danette|Maryjane|Freddie|Delphine|Brianne|Nilda|Danna|Cindi|Bess|Iona|Hanna|Ariel|Winona|Vida|Rosita|Marianna|William|Racheal|Guillermina|Eloisa|Celestine|Caren|Malissa|Lona|Chantel|Shellie|Marisela|Leora|Agatha|Soledad|Migdalia|Ivette|Christen|Athena";

        public static MyDataSet BuildPersons()
        {
            string[] lNames = lastNameString.Split('|');
            string[] fName = firstNameString.Split('|');

            Random rnd = new Random();

            int cnt = Math.Min(lNames.Length, fName.Length);
            if (cnt < 5) cnt += 5;

            MyDataSet ds = new MyDataSet();
            ds.PersonCollection = new PersonCollection();

            for (int idx = 0; idx < cnt; idx++)
            {
                int lnameIdx = rnd.Next(lNames.Length);
                int fnameIdx = rnd.Next(fName.Length);
                bool isHighlighted = rnd.NextDouble() < .5;

                ds.PersonCollection.Add(new Person
                {
                    FirstName = fName[fnameIdx],
                    LastName = lNames[lnameIdx],
                    IsHighlighted = isHighlighted
                }
                );
            }

            return ds;
        }
    }

    public class MyDataSet
    {
        public PersonCollection PersonCollection { get; set; }
    }

    public class PersonCollection : List<Person>
    {
        public PersonCollection()
        {
        }

        public PersonCollection(IList<Person> coll)
            : base(coll)
        {
        }
    }

    public class Person : INotifyPropertyChanged
    {
        private bool _isHighlighted;

        public bool IsHighlighted
        {
            get { return _isHighlighted; }
            set 
            { 
                _isHighlighted = value;
                Fire("IsHighlighted");
            }
        }
        public string FirstName { get; set; }
        public string LastName { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// 
        /// </summary>
        protected virtual void Fire(string propName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propName));
            }
        }
    }
}
